timezone_codes = {
    'IST': 'Asia/Kolkata',
    'PST': 'US/Pacific',
    'EST': 'US/Eastern',
    'CST': 'US/Central',
    'MST': 'US/Mountain',
    'GMT': 'Europe/London',
    'CET': 'Europe/Paris',
    'EET': 'Europe/Athens',
    'JST': 'Asia/Tokyo',
    'AEST': 'Australia/Sydney',
    'UTC': 'UTC'
}